@@ -3,9 +3,10 @@ package manager
 import (
 	"context"
 
+	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
-	"github.com/aws/aws-sdk-go/aws"
 	"github.com/pkg/errors"
+
 	"github.com/weaveworks/goformation/v4"
 )
 
